@@ -3,15 +3,13 @@ from django.contrib import admin
 from mptt.admin import MPTTModelAdmin
 import reversion
 
-from .models import Page, Carousel, CarouselImage, Attachment, Nav, NavItem
+from .models import Page, Carousel, CarouselImage, Attachment, Nav, NavItem, \
+    Redirect
 
 
-class SiteEntityAdmin(reversion.VersionAdmin, admin.ModelAdmin):
-    prepopulated_fields = {"slug": ("title",)}
-    list_editable = ['order', 'status']
-    list_display = ['title', 'slug', 'status', 'order']
-    list_filter = ['status']
-    search_fields = ['title']
+class OrderedAdmin(admin.ModelAdmin):
+    list_editable = ['order']
+    list_display = ['order']
 
     class Media:
         js = (
@@ -22,12 +20,21 @@ class SiteEntityAdmin(reversion.VersionAdmin, admin.ModelAdmin):
         )
 
 
+class SiteEntityAdmin(reversion.VersionAdmin, OrderedAdmin):
+    list_editable = ['order', 'status']
+    list_display = ['title', 'status', 'order']
+    list_filter = ['status']
+    search_fields = ['title']
+
+
 class DisplayableAdmin(SiteEntityAdmin):
-    pass
+    list_display = ['title', 'slug', 'status', 'order']
+    prepopulated_fields = {"slug": ("title",)}
 
 
 class PageAdmin(MPTTModelAdmin, DisplayableAdmin):
-    pass
+    list_display = ['title', 'url', 'status', 'order']
+    exclude = ['url']
 
 admin.site.register(Page, PageAdmin)
 
@@ -60,4 +67,11 @@ class CarouselAdmin(admin.ModelAdmin):
         CarouselImageInline
     ]
 
+
 admin.site.register(Carousel, CarouselAdmin)
+
+
+class RedirectAdmin(OrderedAdmin):
+    list_display = ['old_url', 'new_url', 'order']
+
+admin.site.register(Redirect, RedirectAdmin)
